Calculates the modeling score of a GMWM
model_score(A, D, omega, v_hat, obj_value)A vec
A mat that contains the first derivatives of the processes
A mat that contains the omega used when calculating the GMWM
A mat that contains the covariance matrix
A mat that contains the second derivative of each process
A vec that is the difference of the WV empirical and WV theoretical
The equation is slightly different than that stated in the paper due to the bootstrap already incorporating in N.