A system contains easy-to-use tools as a support for time series analysis courses. In particular, it incorporates a technique called Generalized Method of Wavelet Moments (GMWM) as well as its robust implementation for fast and robust parameter estimation of time series models which is described, for example, in Guerrier et al. (2013) tools:::Rd_expr_doi(" 10.1080/01621459.2013.799920"). More details can also be found in the paper linked to via the URL below.

A system contains easy-to-use tools as a support for time series analysis courses. In particular, it incorporates a technique called Generalized Method of Wavelet Moments (GMWM) as well as its robust implementation for fast and robust parameter estimation of time series models which is described, for example, in Guerrier et al. (2013) tools:::Rd_expr_doi(" 10.1080/01621459.2013.799920"). More details can also be found in the paper linked to via the URL below.
Maintainer: Stéphane Guerrier [email protected] [copyright holder]
Authors:
James Balamuta [copyright holder]
Roberto Molinari [copyright holder]
Justin Lee
Lionel Voirol
Yuming Zhang
Other contributors:
Wenchao Yang [contributor]
Nathanael Claussen [contributor]
Yunxiang Zhang [contributor]
Christian Gunning [copyright holder]
Romain Francois [copyright holder]
Ross Ihaka [copyright holder]
R Core Team [copyright holder]
James Balamuta [email protected], Stephane Guerrier [email protected], Roberto Molinari [email protected], Wenchao Yang [email protected] Justin Lee [email protected] Yuming Zhang [email protected]
The data sets in this package may change at a moments notice.